-inherit boilerplate.html -block title Progress Bar -block extrahead link rel='stylesheet' href='https://cdnjs.cloudflare.com/ajax/libs/materialize/0.97.6/css/materialize.min.css' link rel='stylesheet' href='styles.styl' -block scripts script src='https://code.jquery.com/jquery-3.0.0.min.js' script src='https://cdnjs.cloudflare.com/ajax/libs/materialize/0.97.6/js/materialize.min.js' script src='https://cdn.rawgit.com/brython-dev/brython/3.2.6/www/src/brython.js' script type='text/python' src='client.py' header h1 = title() div.info div.percent 0% progress value='0' max='100' button class='btn waves-effect' Stop div#output